Macros
- impl_
resettable_ buffer - Implements
ResettableBufferfor standard collections.
Structs
- Action
- Represents an index corresponding to a specific legal move or action.
- Engine
- The core Engine handling the Monte Carlo Tree Search algorithm.
- Mcts
Action - A structure bundling a game action with its targeted engine ID.
- Mcts
Batch - The Batch Manager for MCTS Engines.
- Mcts
Config - Configuration for the MCTS batch manager.
- MctsId
- A unique, strongly-typed identifier representing a specific
Engineinstance within theMctsBatchmanager. - Mcts
Node Id - A strictly typed identifier for an instantiated node within the MCTS tree.
- Mcts
Score - A structure bundling the final score array with its targeted engine ID.
- Mcts
Selection Result - Represents the output of a selection phase for a specific engine.
- Mcts
State Evaluation - A structure bundling an MCTS evaluation with its targeted engine ID.
Enums
- Mcts
Engine Error - Errors that can occur during the execution of the MCTS engine.
- Mcts
Error - Errors that can occur when interacting with the
MctsBatchmanager. - Selection
Result - Represents the outcome of a tree selection phase.
- State
Evaluation - Represents the evaluation of a game state, usually provided by a heuristic function or a neural network (e.g., in AlphaZero/MuZero architectures).
Traits
- Resettable
Buffer - A buffer used to store the sequence of actions traversed during the selection phase.
- Score
Transformer - Transforms a score during the backpropagation phase.
- Selection
Function - Evaluates a child node during the tree selection phase.
Functions
- negate_
score - Inverts the evaluation score during the backpropagation phase.
- puct
- Calculates the Predictor + Upper Confidence bound applied to Trees (PUCT) score.
- visits_
to_ probabilities - Converts a raw array of visit counts into a normalized probability distribution.
- visits_
to_ probabilities_ with_ temperature - Converts visit counts into a probability distribution using a temperature parameter.