ResettableBuffer

Trait ResettableBuffer 

pub trait ResettableBuffer {
    // Required methods
    fn push(&mut self, value: Action);
    fn clear(&mut self);
}
A buffer used to store the sequence of actions traversed during the selection phase.

Required Methods

fn push(&mut self, value: Action)

Pushes an action to the end of the buffer.

fn clear(&mut self)

Clears the buffer, removing all elements.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ResettableBuffer for Vec<Action>

Source

fn push(&mut self, value: Action)

Source

fn clear(&mut self)

Implementors